@@ -181,6 +181,8 @@ ffi_enum! {
         Resized = SAPP_EVENTTYPE_RESIZED,
         Iconified = SAPP_EVENTTYPE_ICONIFIED,
         Restored = SAPP_EVENTTYPE_RESTORED,
+        Focused = SAPP_EVENTTYPE_FUCOSUED,
+        Unocused = SAPP_EVENTTYPE_UNFOCUSED,
         /// (Mobile)
         Suspended = SAPP_EVENTTYPE_SUSPENDED,
         /// (Mobile)
@@ -538,6 +540,11 @@ pub fn frame_count() -> u64 {
     unsafe { ffi::sapp_frame_count() }
 }
 
+/// Frame duration in seconds averaged over a number of frames to smooth out any jittering spikes
+pub fn frame_duration() -> u64 {
+    unsafe { ffi::sapp_frame_duration() }
+}
+
 /// (Clipboard) Write string into clipboard
 pub fn set_clipboard(s: &str) -> Result<(), std::ffi::NulError> {
     // unfortunate cost to make it null-terminated
